@@ -102,9 +102,10 @@ class AnsysBinary():
 
 def read_binary(filename, **kwargs):
     """Reads ANSYS-written binary files:
-    - Jobname.RST: result file from structural analysis
+    - Jobname.RST: Result file from structural analysis
+    - Jobname.RTH: Result file from a thermal analysis
     - Jobname.EMAT: Stores data related to element matrices
-    - Jobname.FULL Stores the full stiffness-mass matrix
+    - Jobname.FULL: Stores the full stiffness-mass matrix
 
     Parameters
     ----------
@@ -118,6 +119,7 @@ def read_binary(filename, **kwargs):
     --------
     >>> import pyansys
     >>> result = pyansys.read_binary('file.rst')
+    >>> result = pyansys.read_binary('file.rst')
     >>> full_file = pyansys.read_binary('file.full')
     >>> emat_file = pyansys.read_binary('file.emat')
 
@@ -134,7 +136,6 @@ def read_binary(filename, **kwargs):
     - Jobname.MODE file, storing data related to a modal analysis
     - Jobname.RMG A magnetic analysis
     - Jobname.RFL A FLOTRAN analysis (a legacy results file)
-    - Jobname.RTH A thermal analysis
     """
     if not os.path.isfile(filename):
         raise FileNotFoundError('%s is not a file or cannot be found' %
@@ -151,8 +152,8 @@ def read_binary(filename, **kwargs):
         return FullFile(filename, **kwargs)
     elif file_format == 12:
         from pyansys.rst import ResultFile
-        read_geometry = kwargs.pop('read_geometry', True)
-        result = ResultFile(filename, read_geometry=False, **kwargs)
+        read_mesh = kwargs.pop('read_mesh', True)
+        result = ResultFile(filename, read_mesh=False, **kwargs)
 
         # check if it's a cyclic result file
         ignore_cyclic = kwargs.pop('ignore_cyclic', False)
@@ -160,8 +161,8 @@ def read_binary(filename, **kwargs):
             from pyansys.cyclic_reader import CyclicResult
             return CyclicResult(filename)
 
-        if read_geometry:
-            result._store_geometry()
+        if read_mesh:
+            result._store_mesh()
 
         return result
 
